@@ -4,7 +4,7 @@
 # This is needed on some operators network that filter PC traffic on public APN
 #  based on the user agent (Maemo Browser is seen as Firefox 3.5)
 
-UA_NEW_STRING="Maemo Browser";
+UA_NEW_STRING=`cat /opt/HideUserAgent/UA.txt`;
 UA_PARAM="general.useragent.override";
 UA_SET="user_pref(\"$UA_PARAM\", \"$UA_NEW_STRING\");";
 USER_JS=/home/user/.mozilla/microb/user.js
@@ -13,7 +13,7 @@ PREFS_JS=/home/user/.mozilla/microb/prefs.js
 print_usage()
 {
 	echo "Incorrect supplied arguments";
-	echo "USAGE: $0 [set|remove|get]";
+	echo "USAGE: $0 set|remove|get [ua_string]";
 	echo;
 }
 
@@ -27,11 +27,11 @@ set_ua()
 		# If there is no active useragent string, check if it is commented
 		#  otherwise add it at the end of the file.
 		if [ -z "$UA" ]; then
-			UA=`grep "#user_pref(\"$UA_PARAM" $USER_JS | sed s/#//`;
+			UA=`grep "^#user_pref(\"$UA_PARAM" $USER_JS | sed s/#//`;
 			if [ "$UA" == "$UA_SET" ]; then
 				UA_ESC=$(echo "$UA" | sed 's/\"/\\"/g');
 				cat $USER_JS | sed s/^#"$UA_ESC"/"$UA_ESC"/ > $USER_JS.new;
-				mv $USER_JS $USER_JS.bkp.`date +%Y%m%d%H%M`;
+				#mv $USER_JS $USER_JS.bkp.`date +%Y%m%d%H%M`;
 				mv $USER_JS.new $USER_JS;
 			else
 				echo $UA_SET >> $USER_JS;
@@ -41,8 +41,8 @@ set_ua()
 			#  otherwise don't touch the file
 			if [ "$UA" != "$UA_SET" ]; then
 				UA_ESC=$(echo "$UA" | sed 's/\"/\\"/g');
-				cat $USER_JS | sed s/^"$UA_ESC"/#"$UA_ESC"/ > $USER_JS.new;
-				mv $USER_JS $USER_JS.bkp.`date +%Y%m%d%H%M`;
+				cat $USER_JS | sed /^"$UA_ESC"/d > $USER_JS.new;
+				#mv $USER_JS $USER_JS.bkp.`date +%Y%m%d%H%M`;
 				mv $USER_JS.new $USER_JS;
 				echo $UA_SET >> $USER_JS;
 			fi;
@@ -65,7 +65,7 @@ remove_ua()
 		if [ -n "$UA" ]; then
 			UA_ESC=$(echo "$UA" | sed 's/\"/\\"/g');
 			cat $USER_JS | sed /^"$UA_ESC"/d > $USER_JS.new;
-			mv $USER_JS $USER_JS.bkp.`date +%Y%m%d%H%M`;
+			#mv $USER_JS $USER_JS.bkp.`date +%Y%m%d%H%M`;
 			mv $USER_JS.new $USER_JS;
 		fi;
 	fi;
@@ -77,7 +77,7 @@ remove_ua()
 	if [ -n "$UA" ]; then
 		UA_ESC=$(echo "$UA" | sed 's/\"/\\"/g');
 		cat $PREFS_JS | sed /^"$UA_ESC"/d > $PREFS_JS.new;
-		mv $PREFS_JS $PREFS_JS.bkp.`date +%Y%m%d%H%M`;
+		#mv $PREFS_JS $PREFS_JS.bkp.`date +%Y%m%d%H%M`;
 		mv $PREFS_JS.new $PREFS_JS;
 		pkill -f browserui
 	fi;
